pub struct ChannelLocation {
pub path: Path,
pub kind: ChannelKind,
pub initial_credit: u32,
}Expand description
A precomputed location of a channel within a type structure.
Fields
path: PathPath from the root to this channel.
kind: ChannelKindWhether this is an Rx or Tx channel.
initial_credit: u32Initial credit for this channel, from the const generic N.