pub struct ConnectionSettings {
pub parity: Parity,
pub max_concurrent_requests: u32,
}Expand description
Per-connection limits advertised by a peer.
Fields
parity: ParityWhether this peer will use odd or even IDs for requests and channels on this connection.
max_concurrent_requests: u32Maximum number of in-flight requests this peer is willing to accept on this connection.