MethodDescriptor

Struct MethodDescriptor 

pub struct MethodDescriptor {
    pub id: MethodId,
    pub service_name: &'static str,
    pub method_name: &'static str,
    pub args: &'static [ArgDescriptor],
    pub return_shape: &'static Shape,
    pub doc: Option<&'static str>,
}
Static descriptor for a single RPC method.

Contains static metadata needed for dispatching and calling this method.

Fields

id: MethodId

Method ID (hash of service name, method name, arg shapes, return shape).

service_name: &'static str

Service name (e.g., “Calculator”).

method_name: &'static str

Method name (e.g., “add”).

args: &'static [ArgDescriptor]

Arguments in declaration order.

return_shape: &'static Shape

Return type shape.

doc: Option<&'static str>

Documentation string, if any.