RequestCall

Struct RequestCall 

pub struct RequestCall<'payload> {
    pub method_id: MethodId,
    pub channels: Vec<ChannelId>,
    pub metadata: Metadata<'payload>,
    pub args: Payload<'payload>,
}

Fields

method_id: MethodId

Unique method identifier, hash of fully qualified name + args etc.

channels: Vec<ChannelId>

Channel identifiers, allocated by the caller, that are passed as part of the arguments.

metadata: Metadata<'payload>

Metadata associated with this call

args: Payload<'payload>

Argument tuple