#[repr(u8)]pub enum ChannelBody<'payload> {
Item(ChannelItem<'payload>),
Close(ChannelClose<'payload>),
Reset(ChannelReset<'payload>),
GrantCredit(ChannelGrantCredit),
}Variants
Item(ChannelItem<'payload>)
Send an item on a channel. Channels are not “opened”, they are created implicitly by calls.
Close(ChannelClose<'payload>)
Close a channel — sent by the sender of the channel when they’re gracefully done with a channel.
Reset(ChannelReset<'payload>)
Reset a channel — sent by the receiver of a channel when they would like the sender to please, stop sending items through.
GrantCredit(ChannelGrantCredit)
Grant additional send credit to a channel sender.